@@ -12,9 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import log as logging
 from oslo_utils import timeutils
 import pecan
 import six
+import warnings
 import wsme
 from wsme import types as wtypes
 
@@ -33,6 +35,8 @@ from magnum.common import policy
 from magnum import objects
 from magnum.objects import fields
 
+LOG = logging.getLogger(__name__)
+
 
 class ClusterTemplate(base.APIBase):
     """API representation of a ClusterTemplate.
@@ -152,6 +156,9 @@ class ClusterTemplate(base.APIBase):
     hidden = wsme.wsattr(types.boolean, default=False)
     """Indicates whether the ClusterTemplate is hidden or not."""
 
+    tags = wtypes.StringType(min_length=0, max_length=255)
+    """A comma separated list of tags."""
+
     def __init__(self, **kwargs):
         self.fields = []
         for field in objects.ClusterTemplate.fields:
@@ -252,6 +259,19 @@ class ClusterTemplatesController(base.Controller):
         'detail': ['GET'],
     }
 
+    _devicemapper_overlay_deprecation_note = (
+        "The devicemapper and overlay storage "
+        "drivers are deprecated in favor of overlay2 in docker, and will be "
+        "removed in a future release from docker. Users of the devicemapper "
+        "and overlay storage drivers are recommended to migrate to a "
+        "different storage driver, such as overlay2. overlay2 will be set "
+        "as the default storage driver from Victoria cycle in Magnum.")
+
+    _fedora_atomic_deprecation_note = (
+        "The fedora_atomic driver is deprecated in favor of the fedora_coreos "
+        "driver. Please migrate to the fedora_coreos driver. fedora_atomic "
+        "driver will be remove in a future Magnum version.")
+
     def _generate_name_for_cluster_template(self, context):
         """Generate a random name like: zeta-22-model."""
 
@@ -400,6 +420,18 @@ class ClusterTemplatesController(base.Controller):
                                   do_raise=False):
                 raise exception.ClusterTemplatePublishDenied()
 
+        if (cluster_template.docker_storage_driver in ('devicemapper',
+                                                       'overlay')):
+            warnings.warn(self._devicemapper_overlay_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._devicemapper_overlay_deprecation_note)
+
+        if (cluster_template_dict['coe'] == 'kubernetes' and
+                cluster_template_dict['cluster_distro'] == 'fedora-atomic'):
+            warnings.warn(self._fedora_atomic_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._fedora_atomic_deprecation_note)
+
         # NOTE(yuywz): We will generate a random human-readable name for
         # cluster_template if the name is not specified by user.
         arg_name = cluster_template_dict.get('name')
@@ -414,12 +446,12 @@ class ClusterTemplatesController(base.Controller):
                                                  new_cluster_template.uuid)
         return ClusterTemplate.convert_with_links(new_cluster_template)
 
-    @wsme.validate(types.uuid_or_name, [ClusterTemplatePatchType])
+    @wsme.validate(types.uuid_or_name, [ClusterTemplatePatchType])  # noqa
     @expose.expose(ClusterTemplate, types.uuid_or_name,
                    body=[ClusterTemplatePatchType])
     @validation.enforce_network_driver_types_update()
     @validation.enforce_volume_driver_types_update()
-    def patch(self, cluster_template_ident, patch):
+    def patch(self, cluster_template_ident, patch):   # noqa
         """Update an existing ClusterTemplate.
 
         :param cluster_template_ident: UUID or logic name of a
@@ -467,6 +499,12 @@ class ClusterTemplatesController(base.Controller):
             if cluster_template[field] != patch_val:
                 cluster_template[field] = patch_val
 
+        if (cluster_template.docker_storage_driver in ('devicemapper',
+                                                       'overlay')):
+            warnings.warn(self._devicemapper_overlay_deprecation_note,
+                          DeprecationWarning)
+            LOG.warning(self._devicemapper_overlay_deprecation_note)
+
         cluster_template.save()
         return ClusterTemplate.convert_with_links(cluster_template)
 
