@@ -10,12 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from barbicanclient import client as barbicanclient
+from barbicanclient.v1 import client as barbicanclient
 from glanceclient import client as glanceclient
 from heatclient import client as heatclient
-import mock
 from neutronclient.v2_0 import client as neutronclient
 from novaclient import client as novaclient
+from unittest import mock
 
 from magnum.common import clients
 from magnum.common import exception
@@ -220,8 +220,9 @@ class ClientsTest(base.BaseTestCase):
         self.assertRaises(exception.AuthorizationFailure, obj.barbican)
 
     @mock.patch.object(clients.OpenStackClients, 'keystone')
+    @mock.patch.object(barbicanclient, 'Client')
     @mock.patch.object(clients.OpenStackClients, 'url_for')
-    def test_clients_barbican_cached(self, mock_url, mock_keystone):
+    def test_clients_barbican_cached(self, mock_url, mock_call, mock_keystone):
         con = mock.MagicMock()
         con.auth_url = "keystone_url"
         mock_url.return_value = "url_from_keystone"
@@ -233,6 +234,9 @@ class ClientsTest(base.BaseTestCase):
         barbican = obj.barbican()
         barbican_cached = obj.barbican()
         self.assertEqual(barbican, barbican_cached)
+        mock_call.assert_called_once_with(
+            endpoint='url_from_keystone',
+            session=keystone.session)
 
     @mock.patch.object(novaclient, 'Client')
     @mock.patch.object(clients.OpenStackClients, 'keystone')
